@@ -31,6 +31,20 @@ typedef int ssize_t;
 #define PATH_MAILLOG	"/etc/.osm"
 #endif
 
+#ifdef UNIXWARE1
+#define DONT_CHMOD_SOCKET
+#define O_RSYNC		0
+#define PID_T_IS_LONG_INT
+#define SOCKLEN_T       int
+#define PATH_TMP        "/tmp"
+#define PATH_VAR_TMP    "/var/tmp"
+#define PATH_PASSWD     "/etc/passwd"
+#define PATH_WTMP       "/var/adm/wtmpx"
+#define PATH_UTMP       "/var/adm/utmpx"
+#define PATH_SYSLOG	"/etc/.osm"
+#define PATH_MAILLOG	"/var/mail/:log"
+#endif
+
 #ifdef LINUX2
 #define HAVE_DAEMON
 #define HAVE_GETRUSAGE
@@ -48,8 +62,6 @@ typedef int ssize_t;
 
 #ifdef HPUX10
 #define HAVE_GETRUSAGE
-#define HAVE_SNPRINTF
-#define HAVE_VSNPRINTF
 #define SOCKLEN_T	int
 #define PATH_TMP	"/tmp"
 #define PATH_VAR_TMP	"/var/tmp"
@@ -128,6 +140,24 @@ typedef int ssize_t;
 #define PATH_SYSLOG     "/var/adm/messages"
 #endif
 
+#ifdef MACOSX
+#define HAVE_GETRUSAGE
+#define SIZEOF_IS_LONG_INT
+/* not supported */
+#define O_RSYNC 0
+#define O_SYNC 0
+/* in ansi string.h but undefined in -posix */
+#define bzero(b,len) memset(b,0,len)
+#ifndef FD_CLOEXEC
+#define FD_CLOEXEC	1
+#endif
+#define PATH_TMP        "/private/tmp"
+#define PATH_PASSWD     "/etc/passwd"
+#define PATH_WTMP       "/private/var/log/wtmp"
+#define PATH_UTMP       "/private/var/run/utmp"
+#define PATH_SYSLOG     "/private/var/log/system.log"
+#endif
+
 #ifdef NEXTSTEP3
 #define HAVE_GETRUSAGE
 #define SIZEOF_IS_LONG_INT
@@ -255,7 +285,8 @@ extern void closelog(void);
 #define PATH_PASSWD     "/etc/passwd"
 #define PATH_WTMP       "/var/adm/wtmp"
 #define PATH_UTMP       "/etc/utmp"
-#define PATH_SYSLOG     "/var/adm/syslog"
+#define PATH_SYSLOG     "/var/adm/messages"
+#define PATH_MAILLOG    "/var/log/syslog"
 
 typedef int ssize_t;
 
